Post Test
-----------------------------------------------------

Please answer
the following problems to the best of your ability without any
outside help. You can stop working on a problem after you worked
on it for about five minutes without solving it.

Problems
==============

.. selectquestion:: dclass-post-1-Movie-sq
   :fromid: Classes_Basic_Movie_fix_v3_ac
   :points: 10

.. selectquestion:: dclass-post-2-Rectangle-sq-v2
   :fromid: Classes_Basic_Rectangle_ac_fix_v2
   :points: 10

.. selectquestion:: dclass-post-3-Horse-sq
   :fromid: Classes_Basic_Horse_v2_ac
   :points: 10

.. selectquestion:: dclass-post-4-GasTank-sq
   :fromid: Classes_Basic_GasTank_ac
   :points: 10

.. selectquestion:: dclass-post-5-Dice-sq
   :fromid: Classes_Basic_Dice_fix_v2_ac
   :points: 10


Feedback
==================================

.. shortanswer:: dclass-post-sa

   Please provide feedback here. Please share any comments, problems, or suggestions.

Thank You
============================
Thank you for finishing this assignment!  We appreciate your time on this.
